[PATCH 02/14] -Wmissing-prototypes: proc-service.

Pedro Alves palves@redhat.com
Wed Feb 29 16:17:00 GMT 2012


$ make WERROR_CFLAGS="-Wmissing-prototypes" proc-service.o amd64-linux-nat.o 1>/dev/null
../../src/gdb/proc-service.c:116:1: warning: no previous prototype for ‘ps_pstop’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:125:1: warning: no previous prototype for ‘ps_pcontinue’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:135:1: warning: no previous prototype for ‘ps_lstop’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:145:1: warning: no previous prototype for ‘ps_lcontinue’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:157:1: warning: no previous prototype for ‘ps_lgetxregsize’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:167:1: warning: no previous prototype for ‘ps_lgetxregs’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:177:1: warning: no previous prototype for ‘ps_lsetxregs’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:186:1: warning: no previous prototype for ‘ps_plog’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:200:1: warning: no previous prototype for ‘ps_pglobal_lookup’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:218:1: warning: no previous prototype for ‘ps_pdread’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:227:1: warning: no previous prototype for ‘ps_pdwrite’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:237:1: warning: no previous prototype for ‘ps_ptread’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:246:1: warning: no previous prototype for ‘ps_ptwrite’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:256:1: warning: no previous prototype for ‘ps_lgetregs’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:275:1: warning: no previous prototype for ‘ps_lsetregs’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:294:1: warning: no previous prototype for ‘ps_lgetfpregs’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:314:1: warning: no previous prototype for ‘ps_lsetfpregs’ [-Wmissing-prototypes]
../../src/gdb/proc-service.c:334:1: warning: no previous prototype for ‘ps_getpid’ [-Wmissing-prototypes]
../../src/gdb/amd64-linux-nat.c:442:1: warning: no previous prototype for ‘ps_get_thread_area’ [-Wmissing-prototypes]

arm-linux-nat.c, mips-linux-nat.c, i386-linux-nat.c will warn just
like amd64-linux-nat.c above.

I don't have proc_service.h on my system.  Maybe glibc stopped
installing it at some point?  This patch adds the missing fallback
prototypes to gdb_proc_service.h, under !HAVE_PROC_SERVICE_H, mostly
copied from glibc's proc_service.h.

Build tested on x86_64 Fedora.

2012-02-29  Pedro Alves  <palves@redhat.com>

	Import fallback definitions from glibc.

	* gdb_proc_service.h [!HAVE_PROC_SERVICE_H] (struct
	ps_prochandle): Forward declare.
	(ps_err_e): Use glibc's comments.
	[!HAVE_PROC_SERVICE_H] (ps_pdread, ps_pdwrite, ps_ptread)
	(ps_ptwrite, ps_lgetregs, ps_lsetregs, ps_lgetfpregs)
	(ps_lsetfpregs, ps_getpid, ps_get_thread_area, ps_pglobal_lookup)
	(ps_pstop, ps_pcontinue, ps_lstop, ps_lcontinue, ps_lgetxregsize)
	(ps_lgetxregs, ps_lsetxregs, ps_plog): Declare.
	(struct ps_prochandle): Adjust comment.
---
 gdb/gdb_proc_service.h |  110 ++++++++++++++++++++++++++++++++++++++++++++----
 1 files changed, 101 insertions(+), 9 deletions(-)

diff --git a/gdb/gdb_proc_service.h b/gdb/gdb_proc_service.h
index 42309b8..34167a0 100644
--- a/gdb/gdb_proc_service.h
+++ b/gdb/gdb_proc_service.h
@@ -23,7 +23,31 @@
 
 #ifdef HAVE_PROC_SERVICE_H
 #include <proc_service.h>
-#else
+
+#else /* HAVE_PROC_SERVICE_H */
+
+/* The following fallback definitions have been imported and adjusted
+   from glibc's proc_service.h  */
+
+/* Callback interface for libthread_db, functions users must define.
+   Copyright (C) 1999,2002,2003 Free Software Foundation, Inc.
+   This file is part of the GNU C Library.
+
+   The GNU C Library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2.1 of the License, or (at your option) any later version.
+
+   The GNU C Library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with the GNU C Library; if not, see
+   <http://www.gnu.org/licenses/>.  */
+
+/* The definitions in this file must correspond to those in the debugger.  */
 
 #ifdef HAVE_SYS_PROCFS_H
 #include <sys/procfs.h>
@@ -31,15 +55,16 @@
 
 #include "gregset.h"
 
+/* Functions in this interface return one of these status codes.  */
 typedef enum
 {
-  PS_OK,			/* Success.  */
-  PS_ERR,			/* Generic error.  */
-  PS_BADPID,			/* Bad process handle.  */
-  PS_BADLID,			/* Bad LWP id.  */
-  PS_BADADDR,			/* Bad address.  */
-  PS_NOSYM,			/* Symbol not found.  */
-  PS_NOFREGS			/* FPU register set not available.  */
+  PS_OK,		/* Generic "call succeeded".  */
+  PS_ERR,		/* Generic error. */
+  PS_BADPID,		/* Bad process handle.  */
+  PS_BADLID,		/* Bad LWP identifier.  */
+  PS_BADADDR,		/* Bad address.  */
+  PS_NOSYM,		/* Could not find given symbol.  */
+  PS_NOFREGS		/* FPU register set not available for given LWP.  */
 } ps_err_e;
 
 #ifndef HAVE_LWPID_T
@@ -58,6 +83,73 @@ typedef gdb_gregset_t prgregset_t;
 typedef gdb_fpregset_t prfpregset_t;
 #endif
 
+/* This type is opaque in this interface.  It's defined by the user of
+   libthread_db.  GDB's version is defined below.  */
+struct ps_prochandle;
+
+
+/* Read or write process memory at the given address.  */
+extern ps_err_e ps_pdread (struct ps_prochandle *,
+			   psaddr_t, void *, size_t);
+extern ps_err_e ps_pdwrite (struct ps_prochandle *,
+			    psaddr_t, const void *, size_t);
+extern ps_err_e ps_ptread (struct ps_prochandle *,
+			   psaddr_t, void *, size_t);
+extern ps_err_e ps_ptwrite (struct ps_prochandle *,
+			    psaddr_t, const void *, size_t);
+
+
+/* Get and set the given LWP's general or FPU register set.  */
+extern ps_err_e ps_lgetregs (struct ps_prochandle *,
+			     lwpid_t, prgregset_t);
+extern ps_err_e ps_lsetregs (struct ps_prochandle *,
+			     lwpid_t, const prgregset_t);
+extern ps_err_e ps_lgetfpregs (struct ps_prochandle *,
+			       lwpid_t, prfpregset_t *);
+extern ps_err_e ps_lsetfpregs (struct ps_prochandle *,
+			       lwpid_t, const prfpregset_t *);
+
+/* Return the PID of the process.  */
+extern pid_t ps_getpid (struct ps_prochandle *);
+
+/* Fetch the special per-thread address associated with the given LWP.
+   This call is only used on a few platforms (most use a normal register).
+   The meaning of the `int' parameter is machine-dependent.  */
+extern ps_err_e ps_get_thread_area (const struct ps_prochandle *,
+				    lwpid_t, int, psaddr_t *);
+
+
+/* Look up the named symbol in the named DSO in the symbol tables
+   associated with the process being debugged, filling in *SYM_ADDR
+   with the corresponding run-time address.  */
+extern ps_err_e ps_pglobal_lookup (struct ps_prochandle *,
+				   const char *object_name,
+				   const char *sym_name,
+				   psaddr_t *sym_addr);
+
+
+/* Stop or continue the entire process.  */
+extern ps_err_e ps_pstop (struct ps_prochandle *);
+extern ps_err_e ps_pcontinue (struct ps_prochandle *);
+
+/* Stop or continue the given LWP alone.  */
+extern ps_err_e ps_lstop (struct ps_prochandle *, lwpid_t);
+extern ps_err_e ps_lcontinue (struct ps_prochandle *, lwpid_t);
+
+/* The following are only defined in/called by Solaris.  */
+
+/* Get size of extra register set.  */
+extern ps_err_e ps_lgetxregsize (struct ps_prochandle *ph,
+				 lwpid_t lwpid, int *xregsize);
+/* Get extra register set.  */
+extern ps_err_e ps_lgetxregs (struct ps_prochandle *ph, lwpid_t lwpid,
+			      caddr_t xregset);
+extern ps_err_e ps_lsetxregs (struct ps_prochandle *ph, lwpid_t lwpid,
+			      caddr_t xregset);
+
+/* Log a message (sends to gdb_stderr).  */
+extern void ps_plog (const char *fmt, ...);
+
 #endif /* HAVE_PROC_SERVICE_H */
 
 /* Fix-up some broken systems.  */
@@ -72,7 +164,7 @@ typedef gdb_fpregset_t gdb_prfpregset_t;
 typedef prfpregset_t gdb_prfpregset_t;
 #endif
 
 /* Structure that identifies the target process.  */
 struct ps_prochandle
 {
   /* The LWP we use for memory reads.  */
@@ -72,7 +164,7 @@ typedef gdb_fpregset_t gdb_prfpregset_t;
 #endif
 
-/* Structure that identifies the target process.  */
+/* GDB specific structure that identifies the target process.  */
 struct ps_prochandle
 {



More information about the Gdb-patches mailing list